"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const QuoteNode_1 = require("./QuoteNode");
const StrongNode_1 = require("./StrongNode");
const DecorationNode_1 = require("./DecorationNode");
const CodeNode_1 = require("./CodeNode");
const UrlNode_1 = require("./UrlNode");
const InternalLinkNode_1 = require("./InternalLinkNode");
const IconNode_1 = require("./IconNode");
const HashTagNode_1 = require("./HashTagNode");
const PlainNode_1 = require("./PlainNode");
exports.convertToLineNodes = (text, { nested, quoted } = { nested: false, quoted: false }) => {
    if (!text)
        return [];
    if (!nested && !quoted) {
        const quoteMatch = text.match(QuoteNode_1.quoteRegExp);
        if (quoteMatch) {
            const [, target] = quoteMatch;
            const nodes = exports.convertToLineNodes(target, { nested, quoted: true });
            return [QuoteNode_1.createQuoteNode(nodes)];
        }
    }
    if (!nested) {
        const codeCommandMatch = text.match(CodeNode_1.codeCommandRegExp);
        if (codeCommandMatch) {
            const [, target] = codeCommandMatch;
            return [CodeNode_1.createCodeNode(target)];
        }
        const codeMatch = text.match(CodeNode_1.codeRegExp);
        if (codeMatch) {
            const [, left, target, right] = codeMatch;
            return [
                ...exports.convertToLineNodes(left, { nested, quoted }),
                CodeNode_1.createCodeNode(target),
                ...exports.convertToLineNodes(right, { nested, quoted })
            ];
        }
        const strongMatch = text.match(StrongNode_1.strongRegExp);
        if (strongMatch) {
            const [, left, target, right] = strongMatch;
            return [
                ...exports.convertToLineNodes(left, { nested, quoted }),
                StrongNode_1.createStrongNode(exports.convertToLineNodes(target, { nested: true, quoted })),
                ...exports.convertToLineNodes(right, { nested, quoted })
            ];
        }
        const decorationMatch = text.match(DecorationNode_1.decorationRegExp);
        if (decorationMatch) {
            const [, left, decoChars, target, right] = decorationMatch;
            return [
                ...exports.convertToLineNodes(left, { nested, quoted }),
                DecorationNode_1.createDecorationNode(decoChars, exports.convertToLineNodes(target, { nested: true, quoted })),
                ...exports.convertToLineNodes(right, { nested, quoted })
            ];
        }
    }
    const UrlMatch = text.match(UrlNode_1.urlRegExp) ||
        text.match(UrlNode_1.leftUrlRegExp) ||
        text.match(UrlNode_1.rightUrlRegExp);
    if (UrlNode_1.isUrlMatch(UrlMatch)) {
        const [, left, , , right] = UrlMatch;
        const { href, content = '' } = UrlMatch.groups;
        return [
            ...exports.convertToLineNodes(left, { nested, quoted }),
            UrlNode_1.createUrlNode(href, content),
            ...exports.convertToLineNodes(right, { nested, quoted })
        ];
    }
    const iconMatch = text.match(IconNode_1.iconRegExp);
    if (iconMatch) {
        const [, left, path, , num = '1', right] = iconMatch;
        const iconNode = IconNode_1.createIconNode(path);
        return [
            ...exports.convertToLineNodes(left, { nested, quoted }),
            ...new Array(parseInt(num)).fill(iconNode),
            ...exports.convertToLineNodes(right, { nested, quoted })
        ];
    }
    const internalLinkMatch = text.match(InternalLinkNode_1.internalLinkRegExp);
    if (internalLinkMatch) {
        const [, left, target, right] = internalLinkMatch;
        return [
            ...exports.convertToLineNodes(left, { nested, quoted }),
            InternalLinkNode_1.createInternalLinkNode(target),
            ...exports.convertToLineNodes(right, { nested, quoted })
        ];
    }
    const httpMatch = text.match(UrlNode_1.httpRegExp);
    if (httpMatch) {
        const [, left, target, right] = httpMatch;
        return [
            ...exports.convertToLineNodes(left, { nested, quoted }),
            UrlNode_1.createUrlNode(target, ''),
            ...exports.convertToLineNodes(right, { nested, quoted })
        ];
    }
    const hashTagMatch = text.match(HashTagNode_1.hashTagRegExp);
    if (hashTagMatch) {
        const [, left, target, right] = hashTagMatch;
        return [
            ...exports.convertToLineNodes(left, { nested, quoted }),
            HashTagNode_1.createHashTagNode(target),
            ...exports.convertToLineNodes(right, { nested, quoted })
        ];
    }
    return [PlainNode_1.createPlainNode(text)];
};
//# sourceMappingURL=index.js.map